@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkFocus.c 1.48 97/10/31 09:55:22
+ * RCS: @(#) $Id: tkFocus.c,v 1.2 1998/09/14 18:23:10 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -106,7 +106,7 @@ static void		SetFocus _ANSI_ARGS_((TkWindow *winPtr, int force));
 /*
  *--------------------------------------------------------------
  *
- * Tk_FocusObjCmd --
+ * Tk_FocusCmd --
  *
  *	This procedure is invoked to process the "focus" Tcl command.
  *	See the user documentation for details on what it does.
@@ -121,21 +121,19 @@ static void		SetFocus _ANSI_ARGS_((TkWindow *winPtr, int force));
  */
 
 int
-Tk_FocusObjCmd(clientData, interp, argc, argv)
+Tk_FocusCmd(clientData, interp, argc, argv)
     ClientData clientData;	/* Main window associated with
 				 * interpreter. */
     Tcl_Interp *interp;		/* Current interpreter. */
     int argc;			/* Number of arguments. */
-    Tcl_Obj *CONST argv[];	/* Argument objects. */
+    char **argv;		/* Argument strings. */
 {
-    static char *focusOptions[] = {"-displayof", "-force", "-lastfor",
-				   (char *) NULL};
     Tk_Window tkwin = (Tk_Window) clientData;
     TkWindow *winPtr = (TkWindow *) clientData;
     TkWindow *newPtr, *focusWinPtr, *topLevelPtr;
     ToplevelFocusInfo *tlFocusPtr;
-    char *windowName;
-    int index;
+    char c;
+    size_t length;
 
     /*
      * If invoked with no arguments, just return the current focus window.
@@ -155,12 +153,11 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
      */
 
     if (argc == 2) {
-	windowName = Tcl_GetStringFromObj(argv[1], (int *) NULL);
-	if (windowName[0] == 0) {
+	if (argv[1][0] == 0) {
 	    return TCL_OK;
 	}
-	if (windowName[0] == '.') {
-	    newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
+	if (argv[1][0] == '.') {
+	    newPtr = (TkWindow *) Tk_NameToWindow(interp, argv[1], tkwin);
 	    if (newPtr == NULL) {
 		return TCL_ERROR;
 	    }
@@ -171,18 +168,15 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 	}
     }
 
-    if (Tcl_GetIndexFromObj(interp, argv[1], focusOptions, "option", 0,
-	    &index) != TCL_OK) {
-    	return TCL_ERROR;
-    }
-    if (argc != 3) {
-	Tcl_WrongNumArgs(interp, 2, argv, "window");
-	return TCL_ERROR;
-    }
-    switch (index) {
-      case 0: {        /* -displayof */
-	windowName = Tcl_GetStringFromObj(argv[2], (int *) NULL);
-	newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
+    length = strlen(argv[1]);
+    c = argv[1][1];
+    if ((c == 'd') && (strncmp(argv[1], "-displayof", length) == 0)) {
+	if (argc != 3) {
+	    Tcl_AppendResult(interp, "wrong # args: should be \"",
+		    argv[0], " -displayof window\"", (char *) NULL);
+	    return TCL_ERROR;
+	}
+	newPtr = (TkWindow *) Tk_NameToWindow(interp, argv[2], tkwin);
 	if (newPtr == NULL) {
 	    return TCL_ERROR;
 	}
@@ -190,23 +184,27 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 	if (newPtr != NULL) {
 	    interp->result = newPtr->pathName;
 	}
-	break;
-      }
-      case 1: {        /* -force */
-	windowName = Tcl_GetStringFromObj(argv[2], (int *) NULL);
-	if (windowName[0] == 0) {
+    } else if ((c == 'f') && (strncmp(argv[1], "-force", length) == 0)) {
+	if (argc != 3) {
+	    Tcl_AppendResult(interp, "wrong # args: should be \"",
+		    argv[0], " -force window\"", (char *) NULL);
+	    return TCL_ERROR;
+	}
+	if (argv[2][0] == 0) {
 	    return TCL_OK;
 	}
-	newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
+	newPtr = (TkWindow *) Tk_NameToWindow(interp, argv[2], tkwin);
 	if (newPtr == NULL) {
 	    return TCL_ERROR;
 	}
 	SetFocus(newPtr, 1);
-	break;
-      }
-      case 2: {        /* -lastfor */
-	windowName = Tcl_GetStringFromObj(argv[2], (int *) NULL);
-	newPtr = (TkWindow *) Tk_NameToWindow(interp, windowName, tkwin);
+    } else if ((c == 'l') && (strncmp(argv[1], "-lastfor", length) == 0)) {
+	if (argc != 3) {
+	    Tcl_AppendResult(interp, "wrong # args: should be \"",
+		    argv[0], " -lastfor window\"", (char *) NULL);
+	    return TCL_ERROR;
+	}
+	newPtr = (TkWindow *) Tk_NameToWindow(interp, argv[2], tkwin);
 	if (newPtr == NULL) {
 	    return TCL_ERROR;
 	}
@@ -225,11 +223,10 @@ Tk_FocusObjCmd(clientData, interp, argc, argv)
 		return TCL_OK;
 	    }
 	}
-	break;
-      }
-      default: {
-	panic("bad const entries to focusOptions in focus command");
-      }
+    } else {
+	Tcl_AppendResult(interp, "bad option \"", argv[1],
+		"\": must be -displayof, -force, or -lastfor", (char *) NULL);
+	return TCL_ERROR;
     }
     return TCL_OK;
 }
