@@ -13,37 +13,12 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkSquare.c 1.19 97/07/31 09:13:13
+ * RCS: @(#) $Id: tkSquare.c,v 1.2 1998/09/14 18:23:17 stanton Exp $
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/*
- * Allow this file to be compiled as loadable library (dll) separate
- * from the Tcl shared library (or dll). We don't want all
- * dll symbols to be exported, only the Tksquare_Init() function.
- */
-#undef BUILD_tk
-
 #include "tkPort.h"
-
-#ifdef __cplusplus
-}
-#endif
-
 #include "tk.h"
 
-/*
- * TCL_STORAGE_CLASS is set unconditionally to DLLEXPORT because the
- * Tksquare_Init declaration is in the source file itself, which is only
- * accessed when we are building a library.
- */
-
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS DLLEXPORT
-
 /*
  * A data structure of the following type is kept for each square
  * widget managed by this file:
@@ -126,55 +101,6 @@ static void		SquareEventProc _ANSI_ARGS_((ClientData clientData,
 static int		SquareWidgetCmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *, int argc, char **argv));
 
-/*
- *----------------------------------------------------------------------
- *
- * Tksquare_Init --
- *
- *	This procedure performs intialization for the Tk square
- *	exension.
- *
- * Results:
- *	Returns a standard Tcl completion code, and leaves an error
- *	message in interp->result if an error occurs.
- *
- * Side effects:
- *	Creates several test commands.
- *
- *----------------------------------------------------------------------
- */
-
-EXTERN Tksquare_Init _ANSI_ARGS_((Tcl_Interp *interp));
-
-int
-#ifdef _USING_PROTOTYPES_
-Tksquare_Init (
-    Tcl_Interp *interp)		/* Interpreter for application. */
-#else
-Tksquare_Init(interp)
-    Tcl_Interp *interp;		/* Interpreter for application. */
-#endif
-{
-    /*
-     * Create the square command.
-     */
-
-    if (Tcl_PkgRequire(interp, "Tcl", TCL_VERSION, 1) == NULL) {
-	return TCL_ERROR;
-    }
-    if (Tcl_PkgRequire(interp, "Tk", TK_VERSION, 1) == NULL) {
-	return TCL_ERROR;
-    }
-    if (Tcl_PkgProvide(interp, "Tksquare", TK_VERSION) != TCL_OK) {
-	return TCL_ERROR;
-    }
-
-    Tcl_CreateCommand(interp, "square", SquareCmd,
-	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
-
-    return TCL_OK;
-}
-
 /*
  *--------------------------------------------------------------
  *
