@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMacDraw.c 1.55 97/11/20 18:28:56
+ * RCS: @(#) $Id: tkMacDraw.c,v 1.2 1998/09/14 18:23:35 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -974,26 +974,6 @@ TkMacSetUpGraphicsPort(
     if (gc->line_width > 1) {
 	PenSize(gc->line_width, gc->line_width);
     }
-    if (gc->line_style != LineSolid) {
-	unsigned char *p = (unsigned char *) &(gc->dashes);
-	/*
-	 * Here the dash pattern should be set in the drawing,
-	 * environment, but I don't know how to do that for the Mac.
-	 *
-	 * p[] is an array of unsigned chars containing the dash list.
-	 * A '\0' indicates the end of this list.
-	 *
-	 * Someone knows how to implement this? If you have a more
-	 * complete implementation of SetUpGraphicsPort() for
-	 * the Mac (or for Windows), please let me know.
-	 *
-	 *	Jan Nijtmans
-	 *	NICI (Nijmegen Institute of Cognition and Information)
-	 *	email: Jan.Nijtmans@cmg.nl (work)
-	 *	       Jan.Nijtmans@wxs.nl (private)
-	 *	url:   http://home.wxs.nl/~nijtmans/
-	 */
-    }
 }
 
 /*
