@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkWinMenu.c 1.102 97/10/28 13:56:58
+ * RCS: @(#) $Id: tkWinMenu.c,v 1.3 1998/09/14 18:24:00 stanton Exp $
  */
 
 #define OEMRESOURCE
@@ -582,7 +582,7 @@ ReconfigureWindowsMenu(
     	     * Set enabling and disabling correctly.
     	     */
 
-	    if (mePtr->state == TK_STATE_DISABLED) {
+	    if (mePtr->state == tkDisabledUid) {
 		flags |= MF_DISABLED;
 	    }
     	    
@@ -959,7 +959,7 @@ TkWinHandleMenuEvent(phwnd, pMessage, pwParam, plParam, plResult)
 		    }
 		    if (parentEntryPtr->menuPtr
 			    ->entries[parentEntryPtr->index]->state
-			    != TK_STATE_DISABLED) {
+			    != tkDisabledUid) {
 			TkActivateMenuEntry(parentEntryPtr->menuPtr, 
 				parentEntryPtr->index);
 		    }
@@ -1038,7 +1038,7 @@ TkWinHandleMenuEvent(phwnd, pMessage, pwParam, plParam, plResult)
 		twdPtr->type = TWD_WINDC;
 		twdPtr->winDC.hdc = itemPtr->hDC;
 
-		if (mePtr->state != TK_STATE_DISABLED) {
+		if (mePtr->state != tkDisabledUid) {
 		    if (itemPtr->itemState & ODS_SELECTED) {
 			TkActivateMenuEntry(menuPtr, mePtr->index);
 		    } else {
@@ -1067,8 +1067,7 @@ TkWinHandleMenuEvent(phwnd, pMessage, pwParam, plParam, plResult)
 
 	    if ((flags == 0xFFFF) && (*plParam == 0)) {
 		Tcl_SetServiceMode(oldServiceMode);
-		if (modalMenuPtr && modalMenuPtr->entries &&
-			modalMenuPtr->active && modalMenuPtr->numEntries) {
+		if (modalMenuPtr != NULL) {
 		    RecursivelyClearActiveMenu(modalMenuPtr);
 		}
 	    } else {
@@ -1095,7 +1094,7 @@ TkWinHandleMenuEvent(phwnd, pMessage, pwParam, plParam, plResult)
 			}
 		    }	 
 
-		    if ((mePtr == NULL) || (mePtr->state == TK_STATE_DISABLED)) {
+		    if ((mePtr == NULL) || (mePtr->state == tkDisabledUid)) {
 			TkActivateMenuEntry(menuPtr, -1);
 		    } else {
 			TkActivateMenuEntry(menuPtr, mePtr->index);
@@ -1469,7 +1468,7 @@ DrawMenuEntryIndicator(menuPtr, mePtr, d, gc, indicatorGC, tkfont, fmPtr, x,
 	RECT rect;
 	GC whichGC;
 
-	if (mePtr->state != TK_STATE_NORMAL) {
+	if (mePtr->state != tkNormalUid) {
 	    whichGC = gc;
 	} else {
 	    whichGC = indicatorGC;
@@ -1480,7 +1479,7 @@ DrawMenuEntryIndicator(menuPtr, mePtr, d, gc, indicatorGC, tkfont, fmPtr, x,
 	rect.left = menuPtr->borderWidth + menuPtr->activeBorderWidth + x;
 	rect.right = mePtr->indicatorSpace + x;
 
-	if ((mePtr->state == TK_STATE_DISABLED) && (menuPtr->disabledFg != NULL)
+	if ((mePtr->state == tkDisabledUid) && (menuPtr->disabledFg != NULL)
 		&& (versionInfo.dwMajorVersion >= 4)) {
 	    RECT hilightRect;
 	    COLORREF oldFgColor = whichGC->foreground;
@@ -1498,7 +1497,7 @@ DrawMenuEntryIndicator(menuPtr, mePtr, d, gc, indicatorGC, tkfont, fmPtr, x,
 	DrawWindowsSystemBitmap(menuPtr->display, d, whichGC, &rect, 
 		OBM_CHECK, 0);
 
-	if ((mePtr->state == TK_STATE_DISABLED) 
+	if ((mePtr->state == tkDisabledUid) 
 		&& (menuPtr->disabledImageGC != None)
 		&& (versionInfo.dwMajorVersion < 4)) {
 	    XFillRectangle(menuPtr->display, d, menuPtr->disabledImageGC,
@@ -1550,7 +1549,7 @@ DrawMenuEntryAccelerator(menuPtr, mePtr, d, gc, tkfont, fmPtr,
 
     baseline = y + (height + fmPtr->ascent - fmPtr->descent) / 2;
 
-    if ((mePtr->state == TK_STATE_DISABLED) && (menuPtr->disabledFg != NULL)
+    if ((mePtr->state == tkDisabledUid) && (menuPtr->disabledFg != NULL)
 	    && ((mePtr->accel != NULL)
 	    || ((mePtr->type == CASCADE_ENTRY) && drawArrow))) {
 	if (versionInfo.dwMajorVersion >= 4) {
@@ -1581,7 +1580,7 @@ DrawMenuEntryAccelerator(menuPtr, mePtr, d, gc, tkfont, fmPtr,
 		mePtr->accelLength, leftEdge, baseline);
     }
 
-    if ((mePtr->state == TK_STATE_DISABLED) 
+    if ((mePtr->state == tkDisabledUid) 
 	    && (menuPtr->disabledImageGC != None)
 	    && (versionInfo.dwMajorVersion < 4)) {
 	XFillRectangle(menuPtr->display, d, menuPtr->disabledImageGC,
@@ -1598,7 +1597,7 @@ DrawMenuEntryAccelerator(menuPtr, mePtr, d, gc, tkfont, fmPtr,
 	rect.right = x + width - 1;
 	DrawWindowsSystemBitmap(menuPtr->display, d, gc, &rect, OBM_MNARROW, 
 		ALIGN_BITMAP_RIGHT);
-	if ((mePtr->state == TK_STATE_DISABLED) 
+	if ((mePtr->state == tkDisabledUid) 
 		&& (menuPtr->disabledImageGC != None)
 		&& (versionInfo.dwMajorVersion < 4)) {
 	    XFillRectangle(menuPtr->display, d, menuPtr->disabledImageGC,
@@ -1908,7 +1907,7 @@ DrawMenuEntryLabel(
     	}
     }
 
-    if (mePtr->state == TK_STATE_DISABLED) {
+    if (mePtr->state == tkDisabledUid) {
 	if (menuPtr->disabledFg == NULL) {
 	    XFillRectangle(menuPtr->display, d, menuPtr->disabledGC, x, y,
 		    (unsigned) width, (unsigned) height);
@@ -2082,7 +2081,7 @@ TkpDrawMenuEntry(mePtr, d, tkfont, menuMetricsPtr, x, y, width, height,
      * Choose the gc for drawing the foreground part of the entry.
      */
 
-    if ((mePtr->state == TK_STATE_ACTIVE)
+    if ((mePtr->state == tkActiveUid)
 	    && !strictMotif) {
 	gc = mePtr->activeGC;
 	if (gc == NULL) {
@@ -2097,14 +2096,14 @@ TkpDrawMenuEntry(mePtr, d, tkfont, menuMetricsPtr, x, y, width, height,
     		cascadeEntryPtr = cascadeEntryPtr->nextCascadePtr) {
     	    if (strcmp(cascadeEntryPtr->name, 
     	    	    Tk_PathName(menuPtr->tkwin)) == 0) {
-    	    	if (cascadeEntryPtr->state == TK_STATE_DISABLED) {
+    	    	if (cascadeEntryPtr->state == tkDisabledUid) {
     	    	    parentDisabled = 1;
     	    	}
     	    	break;
     	    }
     	}
 
-	if (((parentDisabled || (mePtr->state == TK_STATE_DISABLED)))
+	if (((parentDisabled || (mePtr->state == tkDisabledUid)))
 		&& (menuPtr->disabledFg != NULL)) {
 	    gc = mePtr->disabledGC;
 	    if (gc == NULL) {
@@ -2244,7 +2243,7 @@ DrawMenuEntryBackground(
     int width,				/* width of rectangle to draw */
     int height)				/* height of rectangle to draw */
 {
-    if (mePtr->state == TK_STATE_ACTIVE) {
+    if (mePtr->state == tkActiveUid) {
 	bgBorder = activeBorder;
     }
     Tk_Fill3DRectangle(menuPtr->tkwin, d, bgBorder,
